package com.jiuqi.util;

package .tmp;

import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;

public class MemOutputStream extends OutputStream {
  private ArrayList buffers;
  
  private byte[] buffer = null;
  
  private int pos = 0;
  
  private int capacity = 1024;
  
  public MemOutputStream() {
    this.buffers = new ArrayList();
  }
  
  public MemOutputStream(int capacity) {
    this.buffers = new ArrayList();
    this.capacity = (capacity > 0) ? capacity : 1024;
  }
  
  public void write(int value) throws IOException {
    if (this.buffer == null) {
      this.buffer = new byte[this.capacity];
      this.buffers.add(this.buffer);
      this.pos = 0;
    } 
    this.buffer[this.pos] = (byte)value;
    this.pos++;
    if (this.pos >= 1024) {
      this.buffer = null;
      this.pos = 0;
    } 
  }
  
  public void reset() {
    this.buffers.clear();
    this.buffer = null;
    this.pos = 0;
  }
  
  public int size() {
    return (this.buffers.size() - 1) * this.capacity + this.pos;
  }
  
  public byte[] toBytes() {
    if (size() <= 0)
      return null; 
    byte[] rt = new byte[size()];
    for (int i = 0; i < this.buffers.size() - 1; i++)
      System.arraycopy(this.buffers.get(i), 0, rt, i * this.capacity, this.capacity); 
    System.arraycopy(this.buffers.get(this.buffers.size() - 1), 0, rt, (this.buffers.size() - 1) * this.capacity, this.pos);
    return rt;
  }
  
  public static void main(String[] args) {
    com.jiuqi.util.MemOutputStream os = new com.jiuqi.util.MemOutputStream();
    String s = new String("测试");
    try {
      byte[] b = s.getBytes();
      for (int i = 0; i < 10; i++)
        os.write(b, 0, b.length); 
      String x = new String(os.toBytes());
      System.out.println(x);
    } catch (Exception exception) {}
  }
}
